function h=MagePlot(A,E)
%h=MagePlot(A,E)
%
% Plot for selecting optimal numbers of components in multiblock regression
% methods such as SO-PLS and PO-PLS, where the number of components can be
% different for each block.
% The prediction error is plottet as function of the total number of
% components.
% 
% 
% INPUT
% A   Combinations of components, size IxB, where B is # blocks and I is number of component combinations.
% E   Vector of prediction errors, size Ix1. Rows correspond to the rows in A.
% 
% OUTPUT
% h   Figure handle
% 
% 
% Example:
% A=A=fullfact([3 3 3])-1; E=rand(size(A,1),1);
% h=MagePlot(A,E)
% 
% References:
% Mge, I., Mevik, B. H., & Ns, T. (2008). Regression models with process variables and parallel blocks of raw material measurements. Journal of Chemometrics, 22(8), 443456.
% Ns, T., Tomic, O., Afseth, N. K., Segtnan, V., & Mge, I. (2013). Multi-block regression based on combinations of orthogonalisation, PLS-regression and canonical correlation analysis. Chemometrics and Intelligent Laboratory Systems, 124, 3242.
% Biancolillo, A., Mge, I., & Ns, T. (2015). Combining SO-PLS and linear discriminant analysis for multi-block classification. Chemometrics and Intelligent Laboratory Systems, 141, 5867. doi:10.1016/j.chemolab.2014.12.001

h=figure;

Asum=sum(A,2);
Arange=unique(Asum);

Emin=ones(1,length(Arange))*inf;
for i=1:size(A,1)
    if E(i)<Emin(find(Arange==Asum(i)))
        Emin(find(Arange==Asum(i)))=E(i);
    end
end
Emin(find(Emin==inf))=[];

lab=char();
for i=1:size(A,2);
    lab=strcat(lab,num2str(A(:,i)));
end
plot(Asum,E,'.k')
text(Asum,E,lab)
hold on
plot(Arange,Emin,'k')
xlabel('Total number of components')
